macro_rules! implement_map_trait_for {
{ $MapTypeName:ident, impl $($impl_line_tokens:tt)* } => { ... };
}Expand description
Macro that defines code to delegate trait methods to the same-named and -typed original methods. This requires the map type name to be given twice, and to use K and V as type names, or the macro wouldn’t work (macros by example do not appear to have the features necessay to do this properly).